@@ -379,7 +379,7 @@ class CodegenMixin(ABC):
         return kwargs
 
 
-class PatternConfig(CodegenMixin, ABC):
+class PatternConfig(CodegenMixin):
     @classmethod
     def format_storage_import(cls, package: str, module_name: str) -> Tuple[str, str]:
         storage_cls = f'{snake_to_pascal(module_name)}Storage'
@@ -1230,6 +1230,7 @@ class DipDupConfig:
         self.paths: List[str] = []
         self.environment: Dict[str, str] = {}
         self._callback_patterns: Dict[str, List[Sequence[HandlerPatternConfigT]]] = defaultdict(list)
+        self._contract_addresses = {contract.address for contract in self.contracts.values()}
 
     @cached_property
     def schema_name(self) -> str:
