@@ -18,12 +18,12 @@ from typing import Tuple
 from typing import Union
 from typing import cast
 
-import humps
 import orjson as json
 from aiohttp import ClientConnectorError
 from aiohttp import ClientOSError
 from aiohttp import ClientResponseError
 from aiohttp import ServerDisconnectedError
+from humps import main as humps
 from pydantic.dataclasses import dataclass
 from tortoise import fields
 
@@ -37,7 +37,6 @@ from dipdup.http import HTTPGateway
 from dipdup.models import Schema
 from dipdup.utils import iter_files
 from dipdup.utils import pascal_to_snake
-from dipdup.utils import snake_to_pascal
 from dipdup.utils.database import get_connection
 from dipdup.utils.database import iter_models
 
@@ -341,13 +340,13 @@ class HasuraGateway(HTTPGateway):
                     metadata_tables[junction_table_name]['object_relationships'].append(
                         self._format_object_relationship(
                             name=related_table_name,
-                            column=self._get_relation_source_field(field),
+                            column=field.forward_key,
                         )
                     )
                     metadata_tables[junction_table_name]['object_relationships'].append(
                         self._format_object_relationship(
                             name=table_name,
-                            column=self._get_relation_source_field(field),
+                            column=field.backward_key,
                         )
                     )
                     if field.related_name:
@@ -355,7 +354,7 @@ class HasuraGateway(HTTPGateway):
                             self._format_array_relationship(
                                 related_name=f'{related_table_name}_{field.related_name}',
                                 table=junction_table_name,
-                                column=self._get_relation_source_field(field),
+                                column=field.forward_key,
                             )
                         )
 
